@@ -10,7 +10,9 @@ from .pyhf_util import (
     bkg_normalization_name,
     create_model,
     get_data,
+    get_init_pars,
     get_par_bounds,
+    get_fixed_params,
     fixed_poi_fit_scan,
     hypotest_scan,
     poi_upper_limit,
@@ -56,15 +58,26 @@ class ABCD:
 
     @property
     def init_pars(self):
-        return self.model.config.suggested_init()
+        return get_init_pars(self.observed_yields, self.model)
 
     @property
     def par_bounds(self):
         return get_par_bounds(self.observed_yields, self.model)
 
-    @property
-    def fixed_params(self):
-        return self.model.config.suggested_fixed()
+    def fixed_params(self, bkg_only=False):
+        return get_fixed_params(self.model, bkg_only=bkg_only)
+
+    def _fixed_poi_fit(self, poi_value):
+        pars = pyhf.infer.mle.fixed_poi_fit(
+            poi_value,
+            data=self.data,
+            pdf=self.model,
+            init_pars=self.init_pars,
+            par_bounds=self.par_bounds,
+            fixed_params=self.fixed_params(),
+            return_uncertainties=True,
+        )
+        return pars
 
     def bkg_only_fit(self):
         pars = pyhf.infer.mle.fixed_poi_fit(
@@ -73,7 +86,7 @@ class ABCD:
             pdf=self.model,
             init_pars=self.init_pars,
             par_bounds=self.par_bounds,
-            fixed_params=self.fixed_params,
+            fixed_params=self.fixed_params(bkg_only=True),
             return_uncertainties=True,
         )
         return pars
@@ -84,7 +97,7 @@ class ABCD:
             pdf=self.model,
             init_pars=self.init_pars,
             par_bounds=self.par_bounds,
-            fixed_params=self.fixed_params,
+            fixed_params=self.fixed_params(),
             return_uncertainties=True,
         )
         return pars
@@ -103,7 +116,7 @@ class ABCD:
                 self.model,
                 self.init_pars,
                 self.par_bounds,
-                self.fixed_params,
+                self.fixed_params(),
             )
             best_fit_pars = np.array(self.fit()).T[0]
             best_fit_twice_nll = pyhf.infer.mle.twice_nll(
@@ -151,7 +164,7 @@ class ABCD:
                     self.model,
                     self.init_pars,
                     self.par_bounds,
-                    self.fixed_params,
+                    self.fixed_params(),
                     return_tail_probs=True,
                     return_expected_set=True,
                 ),
