@@ -91,35 +91,58 @@ def get_data(observed_yields, model):
     return data
 
 
-def get_par_bounds(observed_yields, model):
-    if signal_region not in observed_yields:
-        background_normalization_estimate = (
-            observed_yields[control_regions[0]]
-            * observed_yields[control_regions[1]]
-            / observed_yields[control_regions[2]]
-        )
-        bkg_scale_factor_1_estimate = (
-            observed_yields[control_regions[0]]
-            / background_normalization_estimate
-        )
-        bkg_scale_factor_2_estimate = (
-            observed_yields[control_regions[1]]
-            / background_normalization_estimate
-        )
-    else:
-        background_normalization_estimate = observed_yields[signal_region]
-        bkg_scale_factor_1_estimate = (
-            observed_yields[control_regions[0]]
-            / observed_yields[signal_region]
-        )
-        bkg_scale_factor_2_estimate = (
-            observed_yields[control_regions[1]]
-            / observed_yields[signal_region]
-        )
-    background_normalization_max = (
-        background_normalization_estimate
-        + 5 * math.sqrt(background_normalization_estimate)
+def get_init_pars(observed_yields, model):
+    background_normalization_estimate = (
+        observed_yields[control_regions[0]]
+        * observed_yields[control_regions[1]]
+        / observed_yields[control_regions[2]]
     )
+    bkg_scale_factor_1_estimate = (
+        observed_yields[control_regions[0]] / background_normalization_estimate
+    )
+    bkg_scale_factor_2_estimate = (
+        observed_yields[control_regions[1]] / background_normalization_estimate
+    )
+    init_pars = model.config.suggested_init()
+    init_pars[
+        model.config.par_order.index(bkg_normalization_name)
+    ] = background_normalization_estimate
+    init_pars[
+        model.config.par_order.index(bkg_scale_factor_1_name)
+    ] = bkg_scale_factor_1_estimate
+    init_pars[
+        model.config.par_order.index(bkg_scale_factor_2_name)
+    ] = bkg_scale_factor_2_estimate
+    return init_pars
+
+
+def get_par_bounds(observed_yields, model):
+    background_normalization_estimate = (
+        observed_yields[control_regions[0]]
+        * observed_yields[control_regions[1]]
+        / observed_yields[control_regions[2]]
+    )
+    bkg_scale_factor_1_estimate = (
+        observed_yields[control_regions[0]] / background_normalization_estimate
+    )
+    bkg_scale_factor_2_estimate = (
+        observed_yields[control_regions[1]] / background_normalization_estimate
+    )
+    if (
+        signal_region in observed_yields
+        and observed_yields[signal_region] > background_normalization_estimate
+    ):
+        background_normalization_max = observed_yields[
+            signal_region
+        ] + 5 * math.sqrt(observed_yields[signal_region])
+    else:
+        background_normalization_max = max(
+            (
+                background_normalization_estimate
+                + 5 * math.sqrt(background_normalization_estimate)
+            ),
+            25,
+        )
     poi_max = math.ceil(background_normalization_max)
     par_bounds = model.config.suggested_bounds()
     par_bounds[model.config.par_order.index(poi_name)] = (0, poi_max)
@@ -138,6 +161,15 @@ def get_par_bounds(observed_yields, model):
     return par_bounds
 
 
+def get_fixed_params(model, bkg_only=False):
+    fixed_params = model.config.suggested_fixed()
+    if bkg_only:
+        fixed_params[
+            model.config.par_names().index(signal_uncertainty_name)
+        ] = True
+    return fixed_params
+
+
 def fixed_poi_fit_scan(
     data, model, init_pars, par_bounds, fixed_params, poi_values=None
 ):
